@@ -1,5 +1,5 @@
 from .command import Command  # noqa: F401
 from .options import Explicit, Flag, Implicit, Option, Positional  # noqa: F401
-from .utils import execute  # noqa: F401
+from .utils import CommandResult, execute  # noqa: F401
 
-__version__ = "0.5.5"
+__version__ = "0.5.6"
